#
# spec file for package linstor-client
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define python_linstor 1.12
Name:           linstor-client
Version:        1.12.0
Release:        2.6
Summary:        DRBD distributed resource management utility
License:        GPL-3.0-only
Group:          Productivity/Clustering/HA
URL:            https://github.com/LINBIT/linstor-client
Source:         https://pkg.linbit.com//downloads/linstor/%{name}-%{version}.tar.gz
Patch1:         change-location-of-bash-completion.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module linstor >= %{python_linstor}}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
Requires:       python-linstor >= %{python_linstor}}
%python_subpackages

%description
This client program communicates to a linstor controller node which manages the DRBD9 resources.

%package -n linstor
Summary:        Binaries of linstor client
Group:          Productivity/Clustering/HA

%description -n linstor
Binaries of linstor client

%prep
%autosetup -p1

sed -i '/^#!/d' linstor_client_main.py \
                linstor_client/consts.py \
                linstor_client/utils.py

%build
# man pages included in tarball
%python_build

%install
#python setup.py install --single-version-externally-managed -O1 --root=%{buildroot} --prefix=%{_prefix} --record=INSTALLED_FILES
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%{python_sitelib}

%files -n linstor
%{_bindir}/linstor
%{_datadir}/bash-completion/completions/linstor

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Jan 12 2022 nick wang <nwang@suse.com>
- bsc#1194567, update to 1.12.0
  * Added node evacuate command
  * Added external files commands
  * Fixed parsing exos create ctrl_b_ip
  * Fixed backup machine readable outputs shouldn't be wrapped in list
  * Resource group added adjust command
  * Added snapshot delete --nodes parameter
  * Node list show optional eviction time
  * Node restore added delete resources/snapshots options
  * Resource group added adjust command
  * add client user-agent info
  * node info: show also info for combined nodes
  * Resource involved: remove debug output and an error while filtering
  * Fixed deprecated setup.cfg variable
  * New resource involved command: Show involved resources from a node
  * Added exos commands
  * interactive: fixed help with a command
  * Fixed incorrect git-hash shown in version output
* Thu Dec 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require python-linstor instead of python-module linstor: the
  python singlespec macors will rewrite this to the coresponding
  version, as opposed to python_module, which requires all flavors.
* Tue Jan 26 2021 nick wang <nwang@suse.com>
- bsc#1181397, update to 1.6.1
  * Fix reconnect on timeout error in interactive mode
  * Fix incorrect resource toggle-disk short option -dflt -> --dflt
  * Toggle disk storage pool options are now optional
  * node list now shows DELETING and EVICTED nodes
  * Added diskless placement and additional placement count for auto-place
  * Added node restore command for evicted nodes
  * depend on python-linstor v1.6.0
  * migrate: remove unused AllowLargerVolumeSize property
  * fix incorrect use of argparse.ArgumentTypeError
  * drbd-options: add units to error message
  * Allow setting options via environment variables, prefix is `LS_CLIENT_`
  * Added error-report delete command
  * Commandline choices(enums) are now mostly case insensitive
* Tue Sep 22 2020 nick wang <nwang@suse.com>
- bsc#1176790, update to 1.3.0
  * Added snapshot shipping list command
  * correctly show inactive resources
* Mon Jun  1 2020 nick wang <nwang@suse.com>
- Update to 1.1.2
  * api: support storage-pool list argument for auto select filters
  * rsc-create: fix storage pool argument
  * snapshot list: add resources and nodes filter
  * use gitlab-ci and update tests to use a pre started controller
  * crypt-create-pass: let the user enter passphrase twice
  * property filter support
  * main: remove unused format argument
  * node-list: add option to show aux properties for node
  * drbd-opts: correctly show drbd unit
  * resource-list: add --faulty option, to only show faulty resources
  * node-describe: fix locale/utf8 check
  * add auto-select test and improve diskless on remaining description
  * rsc-grp-spawn: support external name
  * resource-groups: fix missing completers
  * node: improve node ip resolving
  * node: only show satellite nodes info
  * improve: table column headers
  * Add drbd-connection info to resource and volume list output
  * add openflex node create and storage pool create
  * tests: fix suite not returning correct exit code
  * use new ConnectionStatus enum const
  * Fix set property if key with '=' is given
  * rsc-dfn: add auto-place command
  * tests: fix client unittests
  * dm-migrate: fix py2/3 input()
  * dm-migrate: 0-pad current GI
  * dm-migrate: fix overindentation
  * write interactive errors to stderr
  * vlm_dfn: show gross size in list
  * vlm_grp: support gross sizes
  * rsc/vlm-list: do not show unused if state is unknown
  * Added support for SPDK in Physical Storage commands
  * commands: unhide physical storage commands
  * physical-storage: allow storage pool creation
  * commands: remove swordfish support
  * unittest: fix test execution in py3.6 >=
  * packaging: use python3 per default
  * prepare py2/3 pkg split
  [...]
  - Update to 0.9.9-1
  * controller/version: fix --curl mode
  * add linstor authentication arguments
  * add allow-insecure-auth to global args filter
  * tests: better assert for api success
  * Add file and filethin providers
  * Make argument 'ip' of 'n i m' optional
  * Add new conn status for node without stlt conn
  * Allow node to set active stlt conn on netIf crt or mod
  * node_cmds: display only active ip in 'n l'
  [...]
* Tue May 28 2019 nwang@suse.com
- Update to 0.9.5
  - linstor-client/python-linstor 0.9.5
  * Fixed: combined query filters are incorrectly concatenated
  * Fixed: keep-alive (interactive) mode
  * High-Level API: Resource class now works with external names
  - linstor-client/python-linstor 0.9.4
  * API/Client now uses REST-API
  * Added curl command output mode
  * Updated to latest drbd options
  * DRBDManage migrate generator now uses resource transactions
  * Package support for RHEL8
  - linstor-client/python-linstor 0.9.3
  * Support nvme layers
* Tue Apr  9 2019 nwang@suse.com
- Update to 0.9.2
  * Create node IP address will be resolved if not given
  * Removed all name checks, they are checked by the controller anyway
  * Resource definition peer-slots can now be modified
  * DRBD-handlers can now be specified for controller and resource-definition
* Thu Apr  4 2019 nwang@suse.com
- Update to 0.9.1
  * Global compatibility machine readable output
  * Resource definition can now store an unrestricted user name
  * Client fixes to work with py3
  * Improvements on the higher level API Resource object
* Wed Oct 31 2018 nwang@suse.com
- Update to new release 0.7.0
  * Added Proxy configuration commands
  * Synchronous auto-place and storage-pool create commands
  * Resource connection commands (list, props, drbd options)
  * Improved table rendering
  * error list --since allows now hours to be specified
* Wed Sep 26 2018 nwang@suse.com
- bsc#1095668. First version, 0.6.2
  Add patch change-location-of-bash-completion.patch for rpmlint
    warning suse-filelist-forbidden-bashcomp-userdirs
